From a3873bd93caef820eafa8752b14593dff6335a4c Mon Sep 17 00:00:00 2001
From: Aleksander Machniak <alec@alec.pl>
Date: Mon, 08 Dec 2014 04:00:42 -0500
Subject: [PATCH] Enable menu-* actions when UI is locked

---
 program/js/app.js |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/program/js/app.js b/program/js/app.js
index fd0d2e1..a7b45ca 100644
--- a/program/js/app.js
+++ b/program/js/app.js
@@ -630,8 +630,9 @@
     if (obj && obj.blur && !(event && rcube_event.is_keyboard(event)))
       obj.blur();
 
-    // do nothing if interface is locked by other command (with exception for searching reset)
-    if (this.busy && !(command == 'reset-search' && this.last_command == 'search'))
+    // do nothing if interface is locked by another command
+    // with exception for searching reset and menu
+    if (this.busy && !(command == 'reset-search' && this.last_command == 'search') && !command.match(/^menu-/))
       return false;
 
     // let the browser handle this click (shift/ctrl usually opens the link in a new window/tab)

--
Gitblit v1.9.1